@@ -32,5 +32,5 @@ def createEvent(url, params, headers):
 
 
 def updateEvent(url, params, headers):
-    r = requests.put(url+'/events/'+params['event_id'], params=params, headers=headers)
+    r = requests.patch(url+'/events/'+params['event_id'], params=params, headers=headers)
     return r
